@@ -1,4 +1,5 @@
 using System;
+using System.Collections.Generic;
 using System.Text.Json;
 using System.Text.Json.Nodes;
 
@@ -6,6 +7,16 @@ using Json.Schema;
 
 
 bool started = false;
+var options = new ValidationOptions();
+
+
+var drafts = new Dictionary<string, Draft>
+{
+    {"https://json-schema.org/draft/2020-12/schema", Draft.Draft202012},
+    {"https://json-schema.org/draft/2019-09/schema", Draft.Draft201909},
+    {"http://json-schema.org/draft-07/schema#", Draft.Draft7},
+    {"http://json-schema.org/draft-06/schema#", Draft.Draft6},
+};
 
 
 while (Console.ReadLine() is { } line && line != "")
@@ -30,11 +41,34 @@ while (Console.ReadLine() is { } line && line != "")
 					["name"] = "json-everything",
 					["homepage"] = "https://json-everything.net/json-schema/",
 					["issues"] = "https://github.com/gregsdennis/json-everything/issues",
+
+					["dialects"] = new JsonArray
+                                        {
+                                            "https://json-schema.org/draft/2020-12/schema",
+                                            "https://json-schema.org/draft/2019-09/schema",
+                                            "http://json-schema.org/draft-07/schema#",
+                                            "http://json-schema.org/draft-06/schema#",
+                                        },
 				},
 			};
 			Console.WriteLine(startResult.ToJsonString());
 			break;
 
+                case "dialect":
+			if (!started) {
+				throw new NotStarted();
+			}
+                        options = new ValidationOptions{
+                                ValidateAs = drafts[root["dialect"].GetValue<string>()]
+                        };
+
+			var dialectResult = new JsonObject
+			{
+                          ["ok"] = true,
+                        };
+			Console.WriteLine(dialectResult.ToJsonString());
+			break;
+
 		case "run":
 			if (!started) {
 				throw new NotStarted();
@@ -42,14 +76,22 @@ while (Console.ReadLine() is { } line && line != "")
 
 			var testCase = root["case"];
 			var schemaText = testCase["schema"];
+                        var registry = testCase["registry"];
+
+                        options.SchemaRegistry.Fetch = uri =>
+                        {
+                            return registry[uri.ToString()].Deserialize<JsonSchema>();
+                        };
+
 			var schema = schemaText.Deserialize<JsonSchema>();
 			var tests = testCase["tests"].AsArray();
+
                         try {
                             var results = new JsonArray();
 
                             foreach (var test in tests)
                             {
-                                    var validationResult = schema.Validate(test["instance"]);
+                                    var validationResult = schema.Validate(test["instance"], options);
                                     var testResult = new JsonObject
                                     {
                                             ["valid"] = validationResult.IsValid,
