@@ -36,6 +36,7 @@ def image(name):
         )
         yield tag
         await docker.images.delete(name=tag, force=True)
+
     return _image
 
 
@@ -46,7 +47,11 @@ envsonschema = image("envsonschema")
 @asynccontextmanager
 async def bowtie(*args):
     proc = await asyncio.create_subprocess_exec(
-        sys.executable, "-m", "bowtie", "run", *args,
+        sys.executable,
+        "-m",
+        "bowtie",
+        "run",
+        *args,
         stdin=asyncio.subprocess.PIPE,
         stdout=asyncio.subprocess.PIPE,
         stderr=asyncio.subprocess.PIPE,
@@ -57,62 +62,76 @@ async def bowtie(*args):
         stdout, stderr = await proc.communicate(input)
         lines = (json.loads(line.decode()) for line in stdout.splitlines())
 
-        metadata = next(lines)
+        metadata = next(lines, None)
+        assert metadata is not None, stderr
         assert metadata.keys() == {"implementations"}
 
         results = sorted(
             (each for each in lines if "implementation" in each),
             key=lambda each: each["implementation"],
         )
-        return proc.returncode, results, stderr
+        successful, errors = [], []
+        for each in results:
+            if "results" in each:
+                successful.append(each["results"])
+            else:
+                errors.append(each)
+        return proc.returncode, successful, errors, stderr
+
     yield _send
 
 
 @pytest.mark.asyncio
-async def test_lint(lintsonschema):
-    async with bowtie("-i", lintsonschema) as send:
-        returncode, results, stderr = await send(
+async def test_validating_on_both_sides(lintsonschema):
+    async with bowtie("-i", lintsonschema, "-V") as send:
+        returncode, results, _, stderr = await send(
             """
             {"description": "a test case", "schema": {}, "tests": [{"description": "a test", "instance": {}}] }
             """,  # noqa: E501
         )
 
-    got = [
-        [test for test in each["response"]["results"]]
-        for each in results
-    ]
-    assert got == [[{"valid": True}]]
+    assert results == [[{"valid": True}]], stderr
     assert returncode == 0
 
 
 @pytest.mark.asyncio
-async def test_it_runs_tests_from_a_file(tmp_path, lintsonschema):
+async def test_it_runs_tests_from_a_file(tmp_path, envsonschema):
     tests = tmp_path / "tests.jsonl"
-    tests.write_text("""{"description": "foo", "schema": {}, "tests": [{"description": "bar", "instance": {}}] }\n""")  # noqa: E501
-    async with bowtie("-i", lintsonschema, tests) as send:
-        returncode, results, stderr = await send()
+    tests.write_text(
+        """{"description": "foo", "schema": {}, "tests": [{"description": "bar", "instance": {}}] }\n""",  # noqa: E501
+    )
+    async with bowtie("-i", envsonschema, tests) as send:
+        returncode, results, _, stderr = await send()
 
-    got = [
-        [test for test in each["response"]["results"]]
-        for each in results
-    ]
-    assert got == [[{"valid": True}]]
+    assert results == [[{"valid": False}]], stderr
     assert returncode == 0
 
 
 @pytest.mark.asyncio
-async def test_no_tests_run(lintsonschema):
-    async with bowtie("-i", lintsonschema) as send:
-        returncode, results, stderr = await send("")
+async def test_no_tests_run(envsonschema):
+    async with bowtie("-i", envsonschema) as send:
+        returncode, results, _, stderr = await send("")
 
     assert results == []
+    assert stderr != ""
+    assert returncode == os.EX_DATAERR
+
+
+@pytest.mark.asyncio
+async def test_unsupported_dialect(envsonschema):
+    dialect = "some://other/URI/"
+    async with bowtie("-i", envsonschema, "--dialect", dialect) as send:
+        returncode, results, _, stderr = await send("")
+
+    assert results == []
+    assert b"unsupported dialect" in stderr.lower()
     assert returncode == os.EX_DATAERR
 
 
 @pytest.mark.asyncio
 async def test_restarts_crashed_implementations(envsonschema):
     async with bowtie("-i", envsonschema) as send:
-        returncode, results, stderr = await send(
+        returncode, results, _, stderr = await send(
             """
             {"description": "1", "schema": {}, "tests": [{"description": "crash:1", "instance": {}}] }
             {"description": "2", "schema": {}, "tests": [{"description": "a", "instance": {}}] }
@@ -120,18 +139,15 @@ async def test_restarts_crashed_implementations(envsonschema):
             """,  # noqa: E501
         )
 
-    got = [
-        [test for test in each["response"]["results"]]
-        for each in results
-    ]
-    assert got == [[{"valid": False}]]
-    assert returncode == 0
+    assert results == [[{"valid": False}]]
+    assert stderr != ""
+    assert returncode == 0, stderr
 
 
 @pytest.mark.asyncio
 async def test_implementations_can_signal_errors(envsonschema):
     async with bowtie("-i", envsonschema) as send:
-        returncode, results, stderr = await send(
+        returncode, results, _, stderr = await send(
             """
             {"description": "error:", "schema": {}, "tests": [{"description": "crash:1", "instance": {}}] }
             {"description": "4", "schema": {}, "tests": [{"description": "error:message=boom", "instance": {}}] }
@@ -139,26 +155,19 @@ async def test_implementations_can_signal_errors(envsonschema):
             """,  # noqa: E501
         )
 
-    got = [
-        [test for test in each["response"]["results"]]
-        for each in results
-    ]
-    assert got == [[{"valid": True}]]
-    assert returncode == 0
+    assert results == [[{"valid": True}]], stderr
+    assert stderr != ""
+    assert returncode == 0, stderr
 
 
 @pytest.mark.asyncio
 async def test_it_handles_split_messages(envsonschema):
     async with bowtie("-i", envsonschema) as send:
-        returncode, results, stderr = await send(
+        returncode, results, _, stderr = await send(
             """
             {"description": "split:1", "schema": {}, "tests": [{"description": "valid:1", "instance": {}}, {"description": "2 valid:0", "instance": {}}] }
             """,  # noqa: E501
         )
 
-    got = [
-        [test for test in each["response"]["results"]]
-        for each in results
-    ]
-    assert got == [[{"valid": True}, {"valid": False}]]
+    assert results == [[{"valid": True}, {"valid": False}]]
     assert returncode == 0
